@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 import pykka
 
 from mopidy import backend
@@ -8,8 +6,8 @@ from . import playlists
 
 
 class M3UBackend(pykka.ThreadingActor, backend.Backend):
-    uri_schemes = ['m3u']
+    uri_schemes = ["m3u"]
 
     def __init__(self, config, audio):
-        super(M3UBackend, self).__init__()
+        super().__init__()
         self.playlists = playlists.M3UPlaylistsProvider(self, config)
