@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 import json
 
 from mopidy.models import immutable
@@ -37,8 +35,8 @@ def model_json_decoder(dct):
         {u'a_track': Track(artists=[], name=u'name')}
 
     """
-    if '__model__' in dct:
-        model_name = dct.pop('__model__')
+    if "__model__" in dct:
+        model_name = dct.pop("__model__")
         if model_name in immutable._models:
             cls = immutable._models[model_name]
             return cls(**dct)
